summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Changelog-Trunk.txt1
-rw-r--r--src/common/strlib.c4
2 files changed, 3 insertions, 2 deletions
diff --git a/Changelog-Trunk.txt b/Changelog-Trunk.txt
index 46223a3c0..7dff84ae5 100644
--- a/Changelog-Trunk.txt
+++ b/Changelog-Trunk.txt
@@ -1,6 +1,7 @@
Date Added
2010/11/30
+ * Added SV_READDB_MAX_FIELDS define for configuration of the sv_readdb limit. [Ai4rei]
* Made skill_tree.txt reading use sv_readdb. [Ai4rei]
- Added define for skill entry requirements.
- Reports duplicate skills within same job class.
diff --git a/src/common/strlib.c b/src/common/strlib.c
index 7a6c134e7..6a5643558 100644
--- a/src/common/strlib.c
+++ b/src/common/strlib.c
@@ -12,7 +12,7 @@
#include <errno.h>
-
+#define SV_READDB_MAX_FIELDS 63
#define J_MAX_MALLOC_SIZE 65535
// escapes a string in-place (' -> \' , \ -> \\ , % -> _)
@@ -923,7 +923,7 @@ bool sv_readdb(const char* directory, const char* filename, char delim, int minc
FILE* fp;
int lines = 0;
int entries = 0;
- char* fields[64]; // room for 63 fields ([0] is reserved)
+ char* fields[SV_READDB_MAX_FIELDS+1]; // room for SV_READDB_MAX_FIELDS fields ([0] is reserved)
int columns;
char path[1024], line[1024];